ManagedTokenBuilder

Struct ManagedTokenBuilder 

pub struct ManagedTokenBuilder<T> {
    pub token_id: Option<T>,
    pub scopes: Vec<Scope>,
}
A builder to configure a ManagedToken.

Fields

token_id: Option<T>scopes: Vec<Scope>

Implementations

Source

impl<T: Eq + Send + Clone + Display> ManagedTokenBuilder<T>

pub fn with_identifier(&mut self, token_id: T) -> &mut Self

Sets the token identifier to identify and query the managed token.

Setting the identifier is mandatory.

pub fn with_scope(&mut self, scope: Scope) -> &mut Self

Adds a Scope to be granted by the AccessToken.

pub fn with_scopes(&mut self, scopes: Vec<Scope>) -> &mut Self

Adds multiple Scopes to be granted by the AccessToken.

pub fn with_scopes_from_env( &mut self, ) -> StdResult<&mut Self, InitializationError>

Adds Scopes from the environment. They are read from TOKKIT_MANAGED_TOKEN_SCOPES and must be separated by spaces.

pub fn with_scopes_from_selected_env_var( &mut self, env_name: &str, ) -> StdResult<&mut Self, InitializationError>

Adds Scopes from the environment. They are read from an environment variable with the given name and must be separated by spaces.

pub fn build(self) -> StdResult<ManagedToken<T>, InitializationError>

Builds the managed token if properly configured.

Source

impl ManagedTokenBuilder<String>

pub fn with_id_from_env(&mut self) -> StdResult<&mut Self, InitializationError>

Sets the token_id for this managed token from an environment variable. The token_id is read from TOKKIT_MANAGED_TOKEN_ID.

pub fn with_id_from_selected_env_var( &mut self, env_name: &str, ) -> StdResult<&mut Self, InitializationError>

Sets the token_id for this managed token from an environment variable. The token_id is read from an environment variable with the given name.