pub struct AuthorizationRequestError {
pub error: AuthorizationServerErrorCode,
pub error_description: Option<String>,
pub error_uri: Option<String>,
}Expand description
An error in detail returned by the authorization server.
See RFC6749 sec. 5.2
Fields
error: AuthorizationServerErrorCodeThe error code returned from the authorization server
See RFC6749 sec. 5.2
error_description: Option<String>Human-readable ASCII [USASCII] text providing additional information, used to assist the client developer in understanding the error that occurred. Values for the “error_description” parameter MUST NOT include characters outside the set %x20-21 / %x23-5B / %x5D-7E.
See RFC6749 sec. 5.2
error_uri: Option<String>A URI identifying a human-readable web page with information about the error, used to provide the client developer with additional information about the error. Values for the “error_uri” parameter MUST conform to the URI-reference syntax and thus MUST NOT include characters outside the set %x21 / %x23-5B / %x5D-7E.
See RFC6749 sec. 5.2